export { StreamStorageService, StreamStorage, Stream, type CreateStreamProps, type ListStreamsParams, type ListStreamsResponse, type StreamInfo, type StreamSortField, STREAM_MIN_TTL_SECONDS, STREAM_MAX_TTL_SECONDS, STREAM_DEFAULT_TTL_SECONDS, CreateStreamPropsSchema, ListStreamsParamsSchema, ListStreamsResponseSchema, StreamInfoSchema, StreamSortFieldSchema, } from '@agentuity/core/stream';
import { type CreateStreamProps, type ListStreamsParams, type ListStreamsResponse, type StreamInfo, type Stream } from '@agentuity/core/stream';
import { type Logger } from '@agentuity/adapter';
import { z } from 'zod';
export declare const StreamClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type StreamClientOptions = z.infer<typeof StreamClientOptionsSchema>;
export declare class StreamClient {
    #private;
    constructor(options?: StreamClientOptions);
    /**
     * Create a new stream for writing data that can be read multiple times
     */
    create(namespace: string, props?: CreateStreamProps): Promise<Stream>;
    /**
     * Get stream metadata by ID
     */
    get(id: string): Promise<StreamInfo>;
    /**
     * Download stream content
     */
    download(id: string): Promise<ReadableStream<Uint8Array>>;
    /**
     * List streams with optional filtering and pagination
     */
    list(params?: ListStreamsParams): Promise<ListStreamsResponse>;
    /**
     * Delete a stream by its ID
     */
    delete(id: string): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map